# Python Rutext: шаблон

## Введение

Данный проект был вдохновлён одним любительским локальным Discord-ботом. В него добавили новую функцию, генерирующую случайные истории, используя шаблоны текста и случайные вставки.

Получился забавный модуль, но не без недостатков. Так что я захотел сделать свою версию, чтобы если что, помочь таким образом реализовать какие-то фишки, которые предложил я. 🤔

В частности, генерация была абсолютно случайной, .

## Что реализовано

1. Ручной ввод форм;
2. Отсеивание избыточных форм;
3. Относительный формат слов (на основе базы и формата строится форма: `'мирный', '--ая' > 'мирная'`; `'базис', '+ом' > 'базисом'`; `'быть', 'будь' > 'будь'`), позволяющий сократить занимаемую память;
4. Ввод/вывод в YAML (используя кэш, достигается минимум затрат в плане заливов на диск).

## Чего не хватает

1. Шаблоны текстов;
2. Отказоустойчивость;
3. Discord API.